#
# spec file for package dialog
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_date 20230209
%define somajor 15
Name:           dialog
Version:        1.3
Release:        11.3
Summary:        Menus and Input Boxes for Shell Scripts
License:        LGPL-2.1-only
Group:          Development/Tools/Other
URL:            http://invisible-island.net/dialog/
Source0:        https://www.invisible-island.net/archives/%{name}/%{name}-%{version}-%{src_date}.tgz
Source1:        https://www.invisible-island.net/archives/%{name}/%{name}-%{version}-%{src_date}.tgz.asc
Source2:        %{name}.keyring
Source4:        dialog-rpmlintrc
# PATCH-FIX-OPENSUSE : fix shadow during resizing terminal
Patch0:         dialog-1.2-20121230.dif
Patch2:         dialog-gcc-warnings.patch
Patch3:         dialog-1.3-usretc.diff
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
Requires:       terminfo-base
Suggests:       terminfo

%description
This program lets you use menus and dialog boxes in shell scripts.

%package     -n libdialog%{somajor}
Summary:        Menus and Input Boxes for Shell Scripts
Group:          System/Libraries

%description -n libdialog%{somajor}
This program lets you use menus and dialog boxes in shell scripts.

%package        devel
Summary:        Menus and Input Boxes for Shell Scripts
Group:          Development/Libraries/Other
Requires:       libdialog%{somajor} = %{version}

%description    devel
This program lets you use menus and dialog boxes in shell scripts.

%package        examples
Summary:        Examples of using dialog tool
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description    examples
Examples of using menus and dialog boxes in shell scripts.

%lang_package

%prep
%autosetup -n %{name}-%{version}-%{src_date}

%build
    CC=gcc
    LIBS=""
    CFLAGS="%{optflags} -pipe -Wall -D_GNU_SOURCE"
    for ncurses_conf in ncursesw6-config ncurstesw5-config ; do
	ncurses_conf=$(type -p $ncurses_conf 2> /dev/null) || continue
	LIBS="${LIBS:+$LIBS }$($ncurses_conf --libs)"
	CFLAGS="${CFLAGS:+$CFLAGS }$($ncurses_conf --cflags)"
	NCURSES_CONFIG=$ncurses_conf
	export NCURSES_CONFIG
	break
    done
    export CC LIBS CFLAGS

%configure \
    --enable-nls \
    --enable-included-msgs \
    --enable-widec \
    --with-ncursesw \
    --with-libtool \
    --disable-rpath-hack \
    --includedir=%{_includedir}/dialog

# libtool seems to be broken in shell function func_lalib_unsafe_p()
exec 0</dev/null
make %{?_smp_mflags}

%install
# libtool seems to be broken in shell function func_lalib_unsafe_p()
exec 0</dev/null
%make_install

rm -rf %{buildroot}%{_libdir}/.libs
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot}%{_libdir} -name '*.a' -type f -delete -print

rm -rf %{buildroot}%{_datadir}/locale/mg/ # Malagasy (Malayalam??)
rm -rf %{buildroot}%{_datadir}/locale/rm/ # Rhaeto-Romance

mkdir %{buildroot}/etc
> %{buildroot}%{_sysconfdir}/dialogrc
%find_lang %{name}
xz CHANGES

%post -n libdialog%{somajor} -p /sbin/ldconfig
%postun -n libdialog%{somajor} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%if %{defined license}
%license COPYING
%doc CHANGES.xz README VERSION
%else
%doc CHANGES.xz README VERSION COPYING
%endif
%ghost %config(noreplace) %{_sysconfdir}/dialogrc
%{_bindir}/dialog
%{_mandir}/man1/dialog.1%{ext_man}

%files -n libdialog%{somajor}
%defattr(-,root,root)
%{_libdir}/libdialog.so.%{somajor}*

%files devel
%defattr(-,root,root)
%{_bindir}/dialog-config
%{_libdir}/libdialog.so
%{_includedir}/dialog/
%{_mandir}/man3/dialog.3%{ext_man}

%files examples
%defattr(-,root,root)
%doc samples/*

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Nov 23 2023 Ludwig Nussel <lnussel@suse.com>
- don't install config file, dialog has built in defaults anyway
- add support for /usr/etc (dialog-1.3-usretc.diff)
* Mon Jun 19 2023 Dr. Werner Fink <werner@suse.de>
- Update to version 1.3-20230209:
  + install ".pc" files in the test-packages.
  + add pkg-config ".pc" file, for use with the development library.
  + change shared-library configuration in test-packages to use the
    ABI version in the library filename to match its SONAME.
  + add sample scripts to test-packages, using new makefile rule
    "install-examples".
  + corrected cdialog*.install helper scripts in test-package for Debian
  + change ftp URLs in test-packages to https
  + updated configure script, e.g., for compiler-warning fixes.
  + updated fur.po, zh_TW.po from
    http://translationproject.org/latest/dialog/
  + modify slackware.rc to match dialog's output from "make check" using
    this configuration file (FreeBSD #267777).
  + fix shellcheck warnings in helper-scripts for building/installing.
  + updated configure script, e.g., for compiler-warning fixes.
  + updated hu.po from http://translationproject.org/latest/dialog/
  + update config.guess, config.sub, install-sh
  + initialize color-settings before --create-rc option is processed.
  + add "use_scrollbar" setting in rc-file to use in whiptail.rc
  + improve manual page discussion of "--" token.
  + updated configure macro for math-library functions.
  + updated ca.po from http://translationproject.org/latest/dialog/
  + update config.guess
  + fix links in manpages (FreeBSD #264660).
  + document the built-in key bindings which are not part of widgets.
  + updated da.po fa.po is.po, added ka.po from
    http://translationproject.org/latest/dialog/
  + update config.sub
  + adjust fallback bindings for backspace/delete to match the curses
    library's sense of backspace (Arch #74379).
  + amend limit-checks to make --max-input work for sizes greater than
    2048 (Debian #1004874).
  + corrected limit-checks in checklist.c, menubox.c, and treeview.c when
    resizing while the data is scrolled (Debian #1004868).
  + improve logic for updating form-height after screen-resizing.
  + move most of the non-API definitions from dialog.h to dlg_internals.h
  + updated configure macros.
  + update config.guess, config.sub
  + updated es.po, tr.po from http://translationproject.org/latest/dialog/
  + update test-package for Debian to use debhelper.
  + adjust character-offset in editbox.c in case it is past the end of
    the string after trimming (Debian #1003185).
  + updated ro.po from http://translationproject.org/latest/dialog/
  + fix some inconsistent #if vs #ifdef.
  + correct off-by-one limit for month when validating parameters of the
    calendar widget (patch by "viverna", Debian #1000720).
  + modify dlg_yes_labels to not switch to ok/cancel labels if the
    extra button is used (report by Стрижак Андрей).
  + move leak-checking definitions from dialog.h to dlg_internals.h
  + use mktemp utility rather than tempfile for temporary filename in
    the sample scripts (patch by Ville Skyttä).
  + updated id.po, lt.po from http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
  + directly include stddef.h for systems which need it for offsetof().
  + modify gauge's handle_input function to use the file pointer in the
    object in preference to the global dialog_state.
  + correct height-computation for fselect and timebox, broken by fixes
    for auto-layout (Debian #990043, cf: 2019/11/10).
  + improve configure --with-no-leaks option
  + amend adjustment to inputbox height so the autosized dimensions match
    older versions (report by Werner Fink, cf: 2021/01/17).
  + improve configure checks, to reduce warnings during those checks
  + updated fr.po from http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
- Update keyring with latest key of Thomas E. Dickey
* Wed Jun 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.3-20210530:
  + amend adjustment to inputbox height so the autosized dimensions
    match  older versions (boo#1184503).
  + improve configure checks, to reduce warnings during those checks
  + updated translations.
- Changes from version 1.3-20210509:
  + improve configure checks, e.g., for libtool version
- Changes from version 1.3-20210324:
  + add configure option --enable-stdnoreturn to build when C11
    _Noreturn feature is enabled in recent ncurses development.
- Changes from version 1.3-20210319:
  Updated translations.
* Thu Mar 18 2021 Dr. Werner Fink <werner@suse.de>
- Update to version 1.3-20210306
  + add several usage-messages to dialog.pot
  + improve configure-check for ld searchpath on HP-UX and Solaris.
  + fix a few cppcheck warnings
  + updated eo.po, fi.po, pt.po, sq.po, sv.po, ru.po, uk.po, zh_CN.po
    from http://translationproject.org/latest/dialog/
  + updated dialog.pot
  + add option --no-hot-list, to allow suppressing the hotkey feature
    from lists.
  + increase minimum height of inputbox to avoid input field overlapping
    with the button-box (report by Victor Ananjevsky).
  + modify options-parsing to permit a "no" on any boolean option and
    deprecating the "no" options without a "-" , e.g., generalizing on
    "--nook" equivalence to "--no-ok".
  + minor spelling fixes, per codespell
  + update configure macros, for quoting/escaping fixes per shellcheck
  + update config.guess, config.sub
  + modify configure script's compiler check to work around Xcode's
    useless aliases for standard C.
  + enable keep-tite feature for NetBSD 8 and up; earlier releases would
    dump core.
  > new features/fixes (Glenn Herteg)
  + add option "--cursor-off-label"
  + add option "--erase-on-exit"
  + fix errata in manpage.
  + fix logic: dlg_button_to_char() would return wrong value if no
    uppercase was found
  + add DIALOG_TIMEOUT to sample scripts, and use report-button more
    consistently to handle unexpected exit-status values.
  + add dlg_getenv_num() and dlg_getenv_str().
  + add DLG_EXIT_TIMEOUT to allow scripts to exit on an expired timeout
    with an exit-status different from DLG_EXIT_ERROR or DLG_EXIT_ESC
    (patch by Norbert Koch).
  + modify dlg_ok_label() and dlg_ok_labels() to ignore --no-ok if all
    buttons would be omitted.
  + add/use dlg_der_window() to account for derived windows just like
    subwindows, to fix regression in dlg_getc() in fselect/dselect
    widget.
  + modify several widgets to make their handling of --no-ok consistent
    with the majority of the widgets: editbox.c, menubox.c, msgbox.c,
    rangebox.c, textbox.c, timebox.c
  + add ^D as binding for new virtual key DLGK_LEAVE, which will close
    the current dialog by activating the currently-selected button.
  + improve manual-page description of --no-ok option (reports by
    Hans Mueller, Gil Delescluse).
  + modify configure script to make Solaris -R rpath feature work
  + fix regression in dlg_getc() caused by not taking into account
    subwindows used for input (report by Michael Wihl).
  + add validity-checks for window pointer (report/testcase by Michael
    Wihl).
  + improve configure macros:
    CF_CLANG_COMPILER: apply compiler-flags needed for test.
    CF_WITH_SCREEN_PDCURSES: use this to reduce X11-checks.
  + amend initialization for dlg_getc to fix regression in pause widget
    from 2020/03/27 changes (reports by Aidan Tessier, Norbert Koch,
    Josmar Pierri).
  + improve configure macros:
    CF_CLANG_COMPILER: split-out check for -Qunused-arguments to ensure
    that clang supports it.  IBM xlclang does not.
    CF_MIXEDCASE_FILENAMES: when cross-compiling to darwin (macOS),
    assume the filesystem doesn't support mixed-case
  + modify init_dialog's initialization of tab_len and aspect_ratio to
    avoid overwriting initialization done in process_common_options
    (report/patch by Rainer Weikusat, Debian #970508).
  + fix out-of-order description for --tailbox vs --rangebox in manpage
    (report by Glenn Herteg).
  + updated configure-macros: compiler-warnings and shared-library
    options.  Changed configure --with-warnings to --enable-warnings for
    consistency.
  + update config.guess
  + updated sq.po from http://translationproject.org/latest/dialog/
  + add clarification in manual page to show when the single/double
    quotes may be needed (prompted by discussion with Danilo G Baio).
  + fix an extra ".exe" in makefile.in which prevented Cygwin build.
  + fix most cppcheck warnings
  + tailbox/tailboxbg's exit-button now works with mouse-clicks
  + fix repainting while resizing for the editbox widget.
  + add configure-check for curses_exit() from ncurses 6.2
  + fix a few memory leaks in fselect.c, mixedgauge.c when resizing.
  + fix inconsistency in dlg_string_to_argv() which made the checklist9
    example not work.
  + add empty-string check in dlg_print_listitem() to avoid indexing past
    the end of the array of character-offsets.
  + improve handling of KEY_RESIZE by repainting the backtitle after
    clearing the screen (integrated patch by Rainer Weikusat, Debian
    [#954185]).
  + improve logic for wtimeout() calls which are used to set temporary
    non-blocking reads (prompted by patch by Rainer Weikusat, Debian
    [#954220]).
  + add "make check" rule.
  + updated configure-macros.
  + updated configure-macros, to work around ncurses vs xcode's c99 -W
  + update config.guess
  + updated configure-macros.
  + update config.guess
  + correct rc-file lookup of "default" color (report by Grady Martin,
    cf: 2019/09/24).
  + fix several issues in the sample scripts reported by shellcheck.
  + fix a few spelling errors reported by codespell (report by Jens
    Schleusener).
  + correct check for return-value of isblank(), which is not necessarily
    0/1 (report/patch by Paul Cercueil, Peter Korsgaard, cf: 2018/05/31).
  + amend change for parsing command-options before calling init_dialog,
    to handle --no-shadow, etc., which are initialized in init_dialog
    (report by Paul Cercueil, cf: 2018/06/21).
  + add dlg_trace_va_msg to manpage, symbol files.
  + improve layout of several widgets' data area when maximizing.
  + modify dselect/fselect to work with autosizing (Debian #915949).
  + add error messages from dlg_exiterr() to trace file.
  + improve manual page description of escaping in key-bindings.
  + modify inputmenu to recognize the "Cancel" button and keys bound to
    that feature while editing a renamed menu item.
  + revert one change, in form.c to the --last-key feature (Debian
    [#942025]).
  + correct ordering of libraries in configure-script, which appended
    in a case where it should have prepended.
  + update config.guess, config.sub
  + improve dialog-config script's filtering of -L options using the
    linker default directories.
  + improve dialog-config script, adding a -L option corresponding to
    the configure --libdir option if it would be a duplicate (report by
    Andrew Kosteltsev).
  + build-fix for configure --disable-trace
  + updated pt.po from http://translationproject.org/latest/dialog/
  + allow for underline- and reverse-video flags in the ".rc" file
    (integrated patch by Richard Robbins).
  + amend change to --last-key feature to eliminate an unnecessary
    separator (report by Gabriele Balducci).
  + extend --last-key feature to the remaining widgets which have
    ok/cancel buttons, and add logic to map keys which happen to be
    bound to ok/extra/cancel/help to simulate a button-press on the
    corresponding button (report by "sgewrk").
  + further fixes for dialog-config.in (report by Andrew Kosteltsev).
  + modify dialog-config.in so that setting prefix or exec-prefix to
    a given value with --prefix=VALUE or --exec-prefix=VALUE has the
    expected result of changing bindir, etc.
  + correct substitution for $LIBS value in dialog-config.in (report by
    Andrew Kosteltsev).
  + modify dlg_will_resize() and dlg_result_key() functions to reduce
    the chance that dialog exits on a SIGWINCH (Debian #930775).
  + make test-package for the development headers/library
  + add --libs-only-L, etc., to dialog-config script (prompted by
    discussion with Andrew Kosteltsev).
  + fix a memory leak in gauge widget (Andrew Kosteltsev).
  + minor fix for CF_GCC_WARNINGS
  + update config.guess, config.sub
- Modify patch dialog-1.2-20121230.dif
- This update fixes boo#1183668
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Wed Feb 13 2019 Dr. Werner Fink <werner@suse.de>
- Update to version 1.3-20190211
  + modify to work with ncurses' threaded-library, which does not allow
    assignment to LINES/COLS (report by Marcus Roeckrath).
  + correct clearing after text in progressbox from 2018/06/21 changes
    for resizing (reports by David Boyd, Alan Somers).
  + improved configure macros CF_GNU_SOURCE, CF_POSIX_C_SOURCE,
    CF_XOPEN_SOURCE
  + update config.guess, config.sub
- Includes also version 1.3-20181107
  + convert ja.po to UTF-8 for consistency (suggested by Stanislav
    Brabec).
  + repair mis-encoded hi.po (report/analysis by Stanislav Brabec).
- Includes also version 1.3-20181022
  + improved configure macros CF_CC_ENV_FLAGS, CF_LD_RPATH_OPT,
    CF_LIBRARY_PATH, CF_SHARED_OPTS, CF_WITH_MAN2HTML,
    CF_WITH_VERSIONED_SYMS from ncurses
  + add ast.po, from
    http://translationproject.org/latest/dialog/
- Includes also version 1.3-20180621
  + improve file-offset computation in textbox.c (Werner Fink).
  + fix an overlooked case with real_auto_size() to maximize when
    height or width is given as -1.
  + build-fixes for configure options "--disable-Xdialog2" and
    "--disable-form"
  + add traces for each widget to show its parameters.
  + modify color scheme for mixedgauge to use the dialog window colors,
    like the captions.
  + fix a too-small malloc in the mixedgauge widget.
  + fix a use-after-free in dlg_remove_callback().
  + improve handling of SIGWINCH for several widgets (Debian #865840).
    + menubox, the point of the Debian report was that it would be nice
    to increase the window size if the terminal size increases.  Did
    that as a special case less problematic than decreasing the
    terminal size.  Added samples/menubox11 to demonstrate by
    comparison with menubox10 a problem with debconf which puts extra
    newlines in the caption that interfere with autowrap.
    + progressbox and derived prgbox, programbox, now handle resizing.
    + yesno, window was cleared
  + add dlg_ttysize() to support new options, allowing scripts to obtain
    some text-formatting details without initializing the terminal.
  + add options --print-text-only, and --print-text-size for scripts that
    adjust the widget size according to how the captions are formatted.
  + improve dialog.pl:
    + add demo.pl, to demonstrate the functions
    + quote/escape string parameters passed to dialog.
    + ensure all "integer" parameters are really integers.
    + use actual screensize for list captions rather than assuming 24
    lines.
  + when trimming blanks, treat unconverted tabs the same as spaces.
  + correct parameter to test when trimming blanks from the script,
    e.g., with "--trim" (report by Jarno Suni).
  + improve documentation of the various whitespace-filtering options,
    to show which take precedence (Debian #867536, cf: Debian #102942).
  + modify msgbox.c, yesno.c to bind SCROLLKEY_BINDINGS before
    TRAVERSE_BINDINGS so that up/down arrow will by default scroll the
    message up/down rather than be aliases for tab-traversal (report by
    Fredrik Kers).
  + modify dump_one_binding() to show when a binding is overridden.
  + improve format of trace-file, making comment-syntax consistent,
    as well as showing argv-splitting as a series of comments.
  + modify dlg_string_to_argv() to change the quoting behavior to be
    more consistent with shell behavior (patch by Denilson Sa Maia).
  + modify dlg_getc() to return ESC when a timeout expires, notifying
    callers that a quit occurred rather than exiting the application
    (suggested by Rodrigo Freitas).
  + modify handle_inputs() to ensure cursor-visibility is restored when
    there is no input character available (report by Guillaume Vareille).
  + improve comment in manual page regarding which widgets can use the
    "--help-button" (prompted by discussion with Csanyi Pal).
  + add a check for valid object pointer in tailbox's main loop since
    the getc-callback may have been freed within ui_getc.c (report by
    "David").
  + improved configure macros for ncurses: CF_GNU_SOURCE, CF_SHARED_OPTS,
    CF_CURSES_LIBS, CF_CURSES_FUNCS, CF_NCURSES_CONFIG
  + improved configure script checks for groff vs man2html:
    CF_PROG_GROFF and CF_WITH_MAN2HTML
  + build-fix from lynx for AM_WITH_NLS configure macro
  + update config.guess, config.sub
- Remove fix for Hindi translation as now upstream
- Remove patch textbox-file_size.patch now upstream
- Remove dialog.ko.po.bz2 as ko.po now upstream
- Modify patch dialog-1.2-20121230.dif
* Wed Nov  7 2018 sbrabec@suse.com
- Fix mangled Hindi translation (bsc#1115005).
* Tue May 29 2018 werner@suse.de
- Update to version 1.3-20171209
  + update ftp url in test-packages.
  + modify test-packages to use recommended compiler/linker flags.
  + improved configure macros AM_WITH_NLS, CF_CC_ENV_FLAGS,
    CF_CURSES_LIBS, CF_NCURSES_CONFIG, CF_SHARED_OPTS, CF_WITH_LIBTOOL,
    CF__INTL_BODY.
  + update config.guess, config.sub
- Add patch textbox-file_size.patch to fix bug bsc#1094836
* Tue Jun  6 2017 mpluskal@suse.com
- Update to version 1.3-20170509:
  * improved configure macros CF_ADD_CFLAGS, CF_CC_ENV_FLAGS, and
  CF_SHARED_OPTS.
  * updated hu.po and tr.po from
  http://translationproject.org/latest/dialog/
  * update config.guess, config.sub
* Tue Mar  7 2017 p.drouand@gmail.com
- Update to version 1.3-20170131
  * use DLG_TRACE macro consistently to make "--disable-trace" configure
  option work.
  * modify buildlist widget to support option "--reorder" for to allow
    user to reorder the data based on the sequence of selections
    (discussion with Paraic O'Ceallaigh).
  * fill background color on unused parts of buildlist.
  * fix a minor error in buildlist which let pageup switch columns.
  * change several calls to dlg_trace_msg to prefix with "#" to make
    the trace logs more consistent for parsing.
  * add samples/run_test.sh
  * further improve performance with very long command-lines by changes
    to howmany_tags().
  * modify dlg_string_to_argv() to convert escaped double-quotes to
    plain double-quotes when within a double-quoted string.
  * modify makefile to apply CFLAGS to linking
  * modify dlg_string_to_argv() to ignore escaped newlines except when
    quoted, fixing a problem with samples/checklist9.
  * interpret $DIALOGOPTS before expanding "--file", etc., to allow
    the environment variable to turn on tracing in that process.
  * improve performance when processing very long command lines, e.g.,
    using "--file" by changing dialog_opts[] to an array of pointers to
    the expanded argv[] (discussion with Lars Tauber).
  * modified autoconf macros
    + CF_CC_ENV_FLAGS amend the last change to move only the
    preprocessor, optimization and warning flags to CPPFLAGS and
    CFLAGS, leaving the residue in CC.  That happens to work for gcc's
    various "model" options, but may require tuning for other compilers
    + CF_LARGEFILE workaround for clang exit-code vs warnings
    + CF_MATH_LIB quiet strict gcc warning
    + CF_WITH_LIBTOOL fix a few places in configure/build scripts where
    DESTDIR and rpath were combined
    + CF_XOPEN_SOURCE add "uclinux" to list of Linux's
  * update config.guess, config.sub
* Fri Mar 11 2016 mpluskal@suse.com
- Update to 1.3-20160209
  * modify editbox widget to add a trailing newline if the text
    has none to ensure the last line is not ignored (report by
    Florent Rougon).
  * change mouse initialization to look for button-presses rather
    than button-clicks, for better response.
  * modify dump_curses_key() to show mouse-coding in readable form.
  * correct mapping of mouse-clicks on the day-grid in calendar
    widget when "--week-start" is used to set the start of the week
    (report by Stefan Vogtner).
  * integrated changes from Stefan Vogtner:
  * use Gregorian algorithm for leap year
  * use mktime if available; calendar was written just as it became
    standard.
- Changes for version 1.3
  * correct --infobox documentation, which said it shows an OK
    button.
  * fix a couple of place in test-scripts which referred to
    $SIG_TRAP rather than $SIG_QUIT
  * reorganize dialog.3, to use subsections for generating navigation
    pane, using man2html
  * add "--week-start" option for calendar widget (prompted by
    discussion with Stefan Vogtner).
  * add a limit-check in editbox.c to ensure that mouse-clicks
    outside the filled-in text area do not access past the end of
    the array (report by Stefan Vogtner).
  * update configure macros from ncurses changes.
  * update config.guess, config.sub
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 1.2-20150920
  * decrease table value for minimum number of arguments for the
    widgets which use --no-items option
  * update configure macros:
    + use $SHELL consistently, deprecate non-POSIX shell
    + PKG_CONFIG may simply be unset - fix
    + add option to allow changing ABI version, from ncurses6.
  * fixes for two autoconf macros, CF_ADD_INCDIR and
    CF_NCURSES_CONFIG from work on ncurses.
  * build-fix for NetBSD curses
- Fix typo in previous changelog entry
* Fri May 22 2015 mpluskal@suse.com
- Add gpg signature
- Update to 1.2-20150513
  + add configure option --with-install-prefix, like ncurses.
  + add --with-screen and related configure options from ncurses-examples
    to allow building with ncurses6 test-packages.
  + update configure macros for improved coding style from lynx changes.
  + updated ro.po from
    http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
  > patches by Florent Rougon:
  + fix two bugs in the "--file" option.
    + When the number of arguments read from the included file is 0, the
    code used to just skip over '--file' and its argument instead of
    removing them from the argument list, causing "Error:  Unknown
    option --file" later on.
    + In the alternative case (at least one argument read from the file),
    the previous code used to do '--j;' in order to "force rescan" of
    the inserted arguments.  However, control then flowed to outer
    blocks where a '++j;' counteracted this measure, causing "Error:
    Unknown option --msgbox" (for instance) later on.
  + modify escaping in argv.c to be more uniform, whether or not the
    backslash is found within a parameter.
* Thu Mar  5 2015 werner@suse.de
- Hack around bug in libtool as it seems to be broken in shell
  function func_lalib_unsafe_p() as this does only work if a
  file descriptor 0 exists.
* Wed Mar  4 2015 werner@suse.de
- Update to version 1.2-20150225
  + modify gauge widget to keep from erasing a second gauge widget, e.g.,
    via the "--and-widget" option.  This is a cosmetic change to match
    behavior of dialog 1.0 (report by Jason Orendorf).
  + add configure option "--with-man2html"
  + add configure options for versioned symbols, from ongoing work on
    ncurses.
  + update configure macros, e.g., for shared libraries
- Changes from 1.2- 20150125
  + suppress highlighting of character which denotes an abbreviation or
    shortcut for the OK/Cancel and other buttons for these widgets, which
    use abbreviations for the list shown on the screen:  buildlist,
    checklist/radiobox, menubox, treeview (Debian #775295).
  + add grid up/left and down/right bindings in editbox.c as synonyms for
    field prev and next, respectively when handling the OK/Cancel buttons
    (Debian #775294).
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 1.2-20140911
  + correct malloc-size for change to prgbox.
* Thu Dec 12 2013 p.drouand@gmail.com
- Update to version 1.2-20130928
  + fix a regression in gauge widget from 1.2-20130928 changes;
    dlg_reallocate_gauge() failed when no --title option was given
- Changes from 1.2-20130923
  + fix samples/inputbox6-utf8, which had depended unnecessarily on bash.
  + improve memory caching for wide-character manipulation in gauge
    widget
  + add dlg_reallocate_gauge
  + updated configure macros to use msys changes from ncurses.
  + update config.guess, config.sub
- Changes from 1.2-20130902
  + modify makefile rule to make the ".png" filenames created by groff
    predictable.
  + add option --help-tags to allow scripts to get the item's tag field
    consistently from help- and help-item button results rather than
    getting the item's text for the latter
  + correct manpage discussion of DIALOG_ITEM_HELP versus --item-help,
    as well as --help-button return status
  + correct limit used for --hline option
  + do not print empty "[]" if a --hline option was given with an empty
    value
  + miscellaneous configure script fixes/updates.  In particular, add
    option --with-shared which builds shared libraries without a libtool
    dependency.
  + add FreeBSD port-files for test-builds.
  + update lt.po, add fa.po from
    http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
- Changes from 1.2-20130523
  + modify ifdef in arrows.c to work around packages which use the
    wide-character ncursesw headers with the ncurses library
  + correct workaround for xterm alternate-screen to work with/without
    the fix made in ncurses that makes putp() always write to the
    standard output (Debian #708829).
  + improve limit-checks for checklist, in case the dialog is resized
  + add --last-key option ( Debian #697607).
- Changes from 2013/03/15
  + update zh_TW.po, add an.po from
    http://translationproject.org/latest/dialog/
- Remove dialog-libs.patch; fixed on upstream release
* Fri Jun 21 2013 werner@suse.de
- Require terminfo-base and suggest terminfo to have on many or on
  mostly all terminals valid line graphics (bnc#826171)
* Thu Feb 28 2013 werner@suse.de
- Re-add patch dialog-1.2-20121230.dif: Fix problem with moving
  shadows during terminal resize
- Use a /etc/dialogrc for openSUSE default coloring/shadow defaults
- Re-add Korean language message file
* Fri Feb 22 2013 dmitry_r@opensuse.org
- Update to version 1.2-20121230
  * See included CHANGES file for detailes
* Fri Feb 22 2013 dmitry_r@opensuse.org
- Fix libraries
  * dialog-libs.patch
* Thu Jan 31 2013 cfarrell@suse.com
- license update: LGPL-2.1
  See e.g. editbox.c
* Sun Jan 27 2013 dmitry_r@opensuse.org
- Build with libtool using
- Add devel package
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Sep  8 2010 werner@suse.de
- Disable gpm as it is not used for long time
* Thu Jul  1 2010 werner@suse.de
- Added korean po translation file (bnc#614248)
* Fri Dec 18 2009 jengelh@medozas.de
- Enable parallel build
* Mon Aug 18 2008 werner@suse.de
- Reflect last changes in ncurses
* Thu Aug 14 2008 werner@suse.de
- Update to version 1.1 patchlevel 20080727
- Use new ncurses ABI 6 which has extend mouse and color support
* Thu Apr 10 2008 werner@suse.de
- Update to version 1.1 patchlevel 20080316 which includes our
  shadow patch and is fully compatible with newer ncurses.
* Sat Mar 31 2007 rguenther@suse.de
- Add gpm BuildRequires
* Mon Jul 10 2006 werner@suse.de
- Update to new version 1.0 (20060221 TD)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr  6 2004 werner@suse.de
- More about shadows: Make them resizable.
* Thu Apr  1 2004 werner@suse.de
- Update to UTF-8 workable version, use wide char version (#37850)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Jun 12 2003 coolo@suse.de
- use BuildRoot
- package translations too
* Wed Jan  8 2003 werner@suse.de
- Fix bug#22787: Update to new version 0.92b (20020814 TD)
- Correct shadow support
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Feb 25 2000 werner@suse.de
- Do not highlight shadows
* Fri Feb 25 2000 werner@suse.de
- ioctl: if stdout is not a tty try stdin
- Make PageUp and PageDown work as Up and Down in menubox,
  checkbox, and radiobox.
* Thu Feb 24 2000 werner@suse.de
- Security fix in gauge menu
- /usr/man -> /usr/share/man
- Small optimations for several ncurses versions
- Use RPM_OPT_FLAGS
- Make DEL/BS work on any terminal even if terminfo is broken
- Make dialogrc dump work again
- Make shadow work and enable shadow support
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jan  2 1997 florian@suse.de
  just recompiled for newer ncurses
